@@ -1,3 +1,3 @@
 """Contrib extensions for aiorobokassa."""
 
-__all__ = []
+__all__: list[str] = []
